from msiaLex import modifier,emoticon

def test_negation():
    assert modifier.negation('zh')

def test_intensifier():
    assert modifier.intensifier('zsm')
    
# def test_disjunction():
#     assert modifier.disjunction('en')

def test_stopword():
    assert modifier.stopword('en')

def test_stopword():
    assert modifier.stopword('zh')

def test_emoticon():
    assert emoticon.get_emoji_sentiment_rank('👍')


def negation(lang):
    if(lang == 'en'):
        return ['could not even', 
                'can not even', 
                'suppose to be', 
                'cannot even', 
                'suppose to', 
                'should not',
                'would not', 
                'could not',
                'shall not',
                'might not', 
                'no longer',
                'have not',
                'does not',
                'were not',
                'will not',
                'must not', 
                'need not',
                'can not', 
                'did not',
                'had not',
                'has not',
                'was not', 
                'may not', 
                'no more',
                'no one', 
                'be not', 
                'do not', 
                'nothing', 
                'neither', 
                'cannot',
                'nobody', 
                'never',
                'none', 
                'not', 
                'no']
    
    elif(lang == 'zsm'):
        return ['tidak', 
                'tiada', 
                'bukan',
                'tak']
    
    elif(lang == 'zh'):
        return {
                '从来没有': {'intensity': -1, 'tag': 'd'},
                '从没有': {'intensity': -1, 'tag': 'd'},
                '从来未': {'intensity': -1, 'tag': 'd'},
                '并不会': {'intensity': -1, 'tag': 'd'},
                '并不是': {'intensity': -1, 'tag': 'd'},
                '并没有': {'intensity': -1, 'tag': 'd'},
                '不像是': {'intensity': -1, 'tag': 'd'},
                '说不上': {'intensity': -1, 'tag': 'd'},
                '算不上': {'intensity': -1, 'tag': 'd'},
                '不怎么': {'intensity': -1, 'tag': 'd'},
                '不见得': {'intensity': -1, 'tag': 'd'},
                '决不能': {'intensity': -1, 'tag': 'd'},
                '没什么': {'intensity': -1, 'tag': 'd'},
                '不甚': {'intensity': -1, 'tag': 'd'},
                '别无': {'intensity': -1, 'tag': 'd'},
                '并不': {'intensity': -1, 'tag': 'd'},
                '并未': {'intensity': -1, 'tag': 'd'},
                '并无': {'intensity': -1, 'tag': 'd'},
                '并非': {'intensity': -1, 'tag': 'd'},
                '不是': {'intensity': -1, 'tag': 'd'},
                '不算': {'intensity': -1, 'tag': 'd'},
                '不宜': {'intensity': -1, 'tag': 'd'},
                '不再': {'intensity': -1, 'tag': 'd'},
                '不曾': {'intensity': -1, 'tag': 'd'},
                '从不': {'intensity': -1, 'tag': 'd'},
                '从没': {'intensity': -1, 'tag': 'd'},
                '从未': {'intensity': -1, 'tag': 'd'},
                '从无': {'intensity': -1, 'tag': 'd'},
                '毫不': {'intensity': -1, 'tag': 'd'},
                '毫无': {'intensity': -1, 'tag': 'd'},
                '假装': {'intensity': -1, 'tag': 'd'},
                '决不': {'intensity': -1, 'tag': 'd'},
                '绝非': {'intensity': -1, 'tag': 'd'},
                '没法': {'intensity': -1, 'tag': 'd'},
                '没有': {'intensity': -1, 'tag': 'd'},
                '难以': {'intensity': -1, 'tag': 'd'},
                '难于': {'intensity': -1, 'tag': 'd'},
                '尚未': {'intensity': -1, 'tag': 'd'},
                '才怪': {'intensity': -1, 'tag': 'd'},
                '太过': {'intensity': -1, 'tag': 'd'},
                '未曾': {'intensity': -1, 'tag': 'd'},
                '无法': {'intensity': -1, 'tag': 'd'},
                '永不': {'intensity': -1, 'tag': 'd'},
                '有待': {'intensity': -1, 'tag': 'd'},
                '不必': {'intensity': -1, 'tag': 'd'},
                '不用': {'intensity': -1, 'tag': 'd'},
                '不能': {'intensity': -1, 'tag': 'd'},
                '不会': {'intensity': -1, 'tag': 'd'},
                '不便': {'intensity': -1, 'tag': 'd'},
                '不要': {'intensity': -1, 'tag': 'd'},
                '未能': {'intensity': -1, 'tag': 'd'},
                '无须': {'intensity': -1, 'tag': 'd'},
                '绝不': {'intensity': -1, 'tag': 'd'},
                '无需': {'intensity': -1, 'tag': 'd'},
                '未必': {'intensity': -1, 'tag': 'd'},
                '木有': {'intensity': -1, 'tag': 'd'},
                '不像': {'intensity': -1, 'tag': 'd'},
                '不比': {'intensity': -1, 'tag': 'd'},
                '不': {'intensity': -1, 'tag': 'd'},
                '勿': {'intensity': -1, 'tag': 'd'},
                '没': {'intensity': -1, 'tag': 'd'},
                '别': {'intensity': -1, 'tag': 'd'},
                '无': {'intensity': -1, 'tag': 'd'},
                '难': {'intensity': -1, 'tag': 'd'},
                '非': {'intensity': -1, 'tag': 'd'},
                '未': {'intensity': -1, 'tag': 'd'}
                }
        
def intensifier(lang):
    if(lang == 'en'):
        return {
                'high':['super duper',
                        'very easily',
                        'double up',
                        'a lot of', 
                        'loads of', 
                        'lots of', 
                        'tons of', 
                        'absolutely',
                        'completely', 
                        'definitely', 
                        'extremely', 
                        'totally', 
                        'utterly',
                        'highly',
                        'rather', 
                        'really', 
                        'truly'
                        'quite', 
                        'super',
                        'very', 
                        'much', 
                        'more',
                        'most',
                        'many', 
                        'too',
                        'so'],
                
                'low':['a little bit', 
                       'a bit',
                       'little', 
                       'less']
                }
    
    elif(lang == 'zsm'):
        return {
                'high': ['terlalu', 
                         'sungguh', 
                         'memang',
                         'sangat', 
                         'paling',
                         'banyak',
                         'makin',
                         'lebih',
                         'amat',
                         'agak'],
                
                'low': ['sedikit',
                        'kurang']
                }
    
    elif(lang == 'zh'):
        return {
                '百分之百': {'intensity': 5, 'tag': 'd'},
                '不可开交': {'intensity': 5, 'tag': 'd'},
                '地地道道': {'intensity': 5, 'tag': 'd'},
                '完完全全': {'intensity': 5, 'tag': 'd'},
                '无可估量': {'intensity': 5, 'tag': 'd'},
                '无以复加': {'intensity': 5, 'tag': 'd'},
                '无以伦比': {'intensity': 5, 'tag': 'd'},
                '不是一般': {'intensity': 4, 'tag': 'd'},
                '更进一步': {'intensity': 3, 'tag': 'd'},
                '不丁点儿': {'intensity': -2, 'tag': 'd'},
                '或多或少': {'intensity': -2, 'tag': 'd'},
                '多多少少': {'intensity': -2, 'tag': 'd'},
                '不得了': {'intensity': 5, 'tag': 'd'},
                '十二分': {'intensity': 5, 'tag': 'd'},
                '绝对化': {'intensity': 5, 'tag': 'd'},
                '进一步': {'intensity': 3, 'tag': 'd'},
                '越来越': {'intensity': 3, 'tag': 'd'},
                '不为过': {'intensity': 3, 'tag': 'd'},
                '愈来愈': {'intensity': 3, 'tag': 'd'},
                '大不了': {'intensity': 3, 'tag': 'd'},
                '有点点': {'intensity': -2, 'tag': 'd'},
                '有点儿': {'intensity': -2, 'tag': 'd'},
                '一点儿': {'intensity': -2, 'tag': 'd'},
                '一点点': {'intensity': -2, 'tag': 'd'},
                '倍加': {'intensity': 5, 'tag': 'd'},
                '入骨': {'intensity': 5, 'tag': 'd'},
                '充分': {'intensity': 5, 'tag': 'd'},
                '到头': {'intensity': 5, 'tag': 'd'},
                '到家': {'intensity': 5, 'tag': 'd'},
                '非常': {'intensity': 5, 'tag': 'd'},
                '极度': {'intensity': 5, 'tag': 'd'},
                '极端': {'intensity': 5, 'tag': 'd'},
                '极其': {'intensity': 5, 'tag': 'd'},
                '极为': {'intensity': 5, 'tag': 'd'},
                '截然': {'intensity': 5, 'tag': 'd'},
                '绝顶': {'intensity': 5, 'tag': 'd'},
                '绝对': {'intensity': 5, 'tag': 'd'},
                '莫大': {'intensity': 5, 'tag': 'd'},
                '甚为': {'intensity': 5, 'tag': 'd'},
                '十分': {'intensity': 5, 'tag': 'd'},
                '十足': {'intensity': 5, 'tag': 'd'},
                '完全': {'intensity': 5, 'tag': 'd'},
                '万般': {'intensity': 5, 'tag': 'd'},
                '万分': {'intensity': 5, 'tag': 'd'},
                '万万': {'intensity': 5, 'tag': 'd'},
                '无比': {'intensity': 5, 'tag': 'd'},
                '无度': {'intensity': 5, 'tag': 'd'},
                '已极': {'intensity': 5, 'tag': 'd'},
                '已甚': {'intensity': 5, 'tag': 'd'},
                '异常': {'intensity': 5, 'tag': 'd'},
                '逾常': {'intensity': 5, 'tag': 'd'},
                '之极': {'intensity': 5, 'tag': 'd'},
                '之至': {'intensity': 5, 'tag': 'd'},
                '至极': {'intensity': 5, 'tag': 'd'},
                '最为': {'intensity': 5, 'tag': 'd'},
                '不过': {'intensity': 4, 'tag': 'd'},
                '不少': {'intensity': 4, 'tag': 'd'},
                '不胜': {'intensity': 4, 'tag': 'd'},
                '大为': {'intensity': 4, 'tag': 'd'},
                '多多': {'intensity': 4, 'tag': 'd'},
                '多么': {'intensity': 4, 'tag': 'd'},
                '分外': {'intensity': 4, 'tag': 'd'},
                '格外': {'intensity': 4, 'tag': 'd'},
                '好不': {'intensity': 4, 'tag': 'd'},
                '何等': {'intensity': 4, 'tag': 'd'},
                '很是': {'intensity': 4, 'tag': 'd'},
                '很多': {'intensity': 4, 'tag': 'd'},
                '颇为': {'intensity': 4, 'tag': 'd'},
                '真的': {'intensity': 4, 'tag': 'd'},
                '真是': {'intensity': 4, 'tag': 'd'},
                '实在': {'intensity': 4, 'tag': 'd'},
                '太甚': {'intensity': 4, 'tag': 'd'},
                '特别': {'intensity': 4, 'tag': 'd'},
                '尤其': {'intensity': 4, 'tag': 'd'},
                '尤为': {'intensity': 4, 'tag': 'd'},
                '着实': {'intensity': 4, 'tag': 'd'},
                '更加': {'intensity': 3, 'tag': 'd'},
                '更为': {'intensity': 3, 'tag': 'd'},
                '较为': {'intensity': 3, 'tag': 'd'},
                '那般': {'intensity': 3, 'tag': 'd'},
                '那么': {'intensity': 3, 'tag': 'd'},
                '那样': {'intensity': 3, 'tag': 'd'},
                '如斯': {'intensity': 3, 'tag': 'd'},
                '益发': {'intensity': 3, 'tag': 'd'},
                '尤甚': {'intensity': 3, 'tag': 'd'},
                '愈发': {'intensity': 3, 'tag': 'd'},
                '愈加': {'intensity': 3, 'tag': 'd'},
                '愈益': {'intensity': 3, 'tag': 'd'},
                '远远': {'intensity': 3, 'tag': 'd'},
                '越发': {'intensity': 3, 'tag': 'd'},
                '越加': {'intensity': 3, 'tag': 'd'},
                '越是': {'intensity': 3, 'tag': 'd'},
                '这般': {'intensity': 3, 'tag': 'd'},
                '这样': {'intensity': 3, 'tag': 'd'},
                '足足': {'intensity': 3, 'tag': 'd'},
                '好生': {'intensity': -2, 'tag': 'd'},
                '略加': {'intensity': -2, 'tag': 'd'},
                '略略': {'intensity': -2, 'tag': 'd'},
                '略微': {'intensity': -2, 'tag': 'd'},
                '略为': {'intensity': -2, 'tag': 'd'},
                '稍稍': {'intensity': -2, 'tag': 'd'},
                '稍为': {'intensity': -2, 'tag': 'd'},
                '稍微': {'intensity': -2, 'tag': 'd'},
                '稍许': {'intensity': -2, 'tag': 'd'},
                '未免': {'intensity': -2, 'tag': 'd'},
                '相当': {'intensity': -2, 'tag': 'd'},
                '一些': {'intensity': -2, 'tag': 'd'},
                '些微': {'intensity': -2, 'tag': 'd'},
                '一点': {'intensity': -2, 'tag': 'd'},
                '有点': {'intensity': -2, 'tag': 'd'},
                '有些': {'intensity': -2, 'tag': 'd'},
                '半点': {'intensity': -2, 'tag': 'd'},
                '不大': {'intensity': -2, 'tag': 'd'},
                '轻度': {'intensity': -2, 'tag': 'd'},
                '丝毫': {'intensity': -2, 'tag': 'd'},
                '相对': {'intensity': -2, 'tag': 'd'},
                '最': {'intensity': 5, 'tag': 'd'},
                '贼': {'intensity': 5, 'tag': 'd'},
                '尽': {'intensity': 5, 'tag': 'd'},
                '极': {'intensity': 5, 'tag': 'd'},
                '太': {'intensity': 4, 'tag': 'd'},
                '真': {'intensity': 4, 'tag': 'd'},
                '多': {'intensity': 4, 'tag': 'd'},
                '特': {'intensity': 4, 'tag': 'd'},
                '很': {'intensity': 4, 'tag': 'd'},
                '好': {'intensity': 4, 'tag': 'd'},
                '尤': {'intensity': 4, 'tag': 'd'},
                '可': {'intensity': 4, 'tag': 'd'},
                '颇': {'intensity': 4, 'tag': 'd'},
                '甚': {'intensity': 4, 'tag': 'd'},
                '益': {'intensity': 3, 'tag': 'd'},
                '更': {'intensity': 3, 'tag': 'd'},
                '较': {'intensity': 3, 'tag': 'd'},
                '超': {'intensity': 3, 'tag': 'd'},
                '忒': {'intensity': 3, 'tag': 'd'},
                '逾': {'intensity': 3, 'tag': 'd'},
                '愈': {'intensity': 3, 'tag': 'd'},
                '微': {'intensity': -2, 'tag': 'd'},
                '蛮': {'intensity': -2, 'tag': 'd'},
                '稍': {'intensity': -2, 'tag': 'd'},
                '挺': {'intensity': -2, 'tag': 'd'},
                '略': {'intensity': -2, 'tag': 'd'}
                }

def conjunction(lang):
    if(lang == 'en'):
        return {
                'contrasting':['on the other hand', 
                               'on the contrary',
                               'in contrast', 
                               'even though',
                               'except that', 
                               'alternatively',
                               'nevertheless',
                               'conversely',
                               'although',
                               'however', 
                               'instead', 
                               'whereas', 
                               'but']
                }
    
    elif(lang == 'zsm'):
        return {
                'contrasting':['walau bagaimanapun', 
                               'walaupun demikian', 
                               'walaupun begitu',
                               'walhal itu', 
                               'sebaliknya',
                               'walaupun',
                               'kecuali',
                               'tetapi']
                }
    
    elif(lang == 'zh'):
        return {'contrasting':
                    {
                        '但是': {'intensity': 3, 'tag': 'c'},
                        '然而': {'intensity': 3, 'tag': 'c'},
                        '偏偏': {'intensity': 3, 'tag': 'c'},
                        '只是': {'intensity': 3, 'tag': 'c'},
                        '就是': {'intensity': 3, 'tag': 'c'},
                        '不过': {'intensity': 3, 'tag': 'c'},
                        '可是': {'intensity': 3, 'tag': 'c'},
                        '不料': {'intensity': 3, 'tag': 'c'},
                        '岂知': {'intensity': 3, 'tag': 'c'},
                        '但': {'intensity': 3, 'tag': 'c'},
                        '而': {'intensity': 3, 'tag': 'c'},
                        '却': {'intensity': 3, 'tag': 'c'}
                    }
                }
        
def stopword(lang):
    if(lang == 'en'):
        return ['a','about','above','across','after','afterwards','again','against','all','almost','alone','along','already','also','although','always','am',
                'among','amongst','amoungst','amount','an','and','another','any','anyhow','anyone','anything','anyway','anywhere','are','around','as','at',
                'back','be','became','because','become','becomes','becoming','been','before','beforehand','behind','being','below','beside','besides','between','beyond','bill','both','bottom','but','by',
                'can','cannot','cant','co','could','couldnt',
                'de','did','didn','do','does','doesn','doing','don','done','down','due','during',
                'each','eg','eight','either','eleven','else','elsewhere','etc','even','ever','every','everyone','everything','everywhere','except',
                'few','fifteen','fifty','fill','find','first','five','for','former','formerly','forty','found','four','from','front','further',
                'had','has','hasnt','have','he','hence','her','here','hereafter','hereby','herein','hereupon','hers','herself','him','himself','his','how','however','hundred',
                'i','ie','if','in','inc','indeed','into','is','it','its','itself',
                'just',
                'keep','kg','km',
                'last','latter','latterly','least','less','ltd',
                'made','make','many','may','me','meanwhile','might','mill','mine','more','moreover','most','mostly','move','much','must','my','myself',
                'name','namely','neither','never','nevertheless','next','nine','no','nobody','none','noone','nor','not','nothing','now','nowhere',
                'of','off','often',
                'on','once','one','only','onto','or','other','others','otherwise','our','ours','ourselves','out','over','own',
                'part','per','perhaps','please','put',
                'quite',
                'rather','re','really','regarding',
                'same','say','see','seem','seemed','seeming','seems','several','she','should','side','since','six','sixty','so','some','somehow','someone','something','sometime','sometimes','somewhere','still','such',
                'ten','than','that','the','their','them','themselves','then','thence','there','thereafter','thereby','therefore','therein','thereupon','these','they','third','this','those','though','three','through','throughout','thru','thus','to','together','too','toward','towards','twelve','twenty','two',
                'un','under','unless','until','up','upon','us','used','using',
                'various','very','via',
                'was','we','were','what','whatever','when','whence','whenever','where','whereafter','whereas','whereby','wherein','whereupon','wherever','whether','which','while','whither','who','whoever','whole','whom','whose','why','will','with','within','without','would',
                'yet','you','your','yours','yourself','yourselves']
    elif(lang == 'zsm'):
        return ['abang', 'acapkali', 'ada', 'adakah', 'adakan', 'adalah', 'adanya', 'adapun', 'agak', 'agaknya', 'agar', 'akan', 'akankah', 'akhir', 'akhiri', 'akhirnya', 'aku', 'akulah', 'akupun', 'al', 'alangkah', 'alkisah', 'allah', 'amat', 'amatlah', 'anda', 'andalah', 'antar', 'antara', 'antaramu', 'antaranya', 'apa', 'apa-apa', 'apaan', 'apabila', 'apakah', 'apalagi', 'apapun', 'apatah', 'arakian', 'artinya', 'as', 'asal', 'asalam', 'asalkan', 'assalam', 'assalamualaikum', 'atas', 'atasmu', 'atasnya', 'atau', 'ataukah', 'ataupun', 'atuk', 'awak', 'awal', 'awalnya', 'ayah', 
                'baba', 'bagai', 'bagaikan', 'bagaimana', 'bagaimanakah', 'bagaimanapun', 'bagi', 'bagian', 'bagimu', 'baginda', 'baginya', 'bahawa', 'bahawasanya', 'bahkan', 'bahwa', 'bahwasanya', 'bak', 'bakal', 'bakalan', 'balik', 'bang', 'banyak', 'banyaknya', 'bapak', 'barangkali', 'barangsiapa', 'baru', 'bawah', 'beberapa', 'begini', 'beginian', 'beginikah', 'beginilah', 'begitu', 'begitukah', 'begitulah', 'begitupun', 'belaka', 'belakang', 'belakangan', 'belas', 'beliau', 'belum', 'belumkah', 'belumlah', 'benar', 'benarkah', 'benarlah', 'berada', 'berakhir', 'berakhirlah', 'berakhirnya', 'berapa', 'berapakah', 'berapalah', 'berapapun', 'berarti', 'berawal', 'berbagai', 'berdatangan', 'berikut', 'berikutnya', 'beriman', 'berjumlah', 'berkali-kali', 'berkata', 'berkehendak', 'berkeinginan', 'berkenaan', 'berkenan', 'berlainan', 'berlalu', 'berlangsung', 'berlebihan', 'bermacam', 'bermacam-macam', 'bermaksud', 'bermula', 'bersama', 'bersama-sama', 'bersiap', 'bersiap-siap', 'berujar', 'berupa', 'beserta', 'beta', 'betulkah', 'biar', 'biarpun', 'biasa', 'biasanya', 'bila', 'bilakah', 'bilamana', 'bin', 'binti', 'bir', 'bisa', 'bisakah', 'blum', 'bn', 'bnt', 'bole', 'boleh', 'bolehkah', 'bolehlah', 'bt', 'buat', 'bukan', 'bukankah', 'bukanlah', 'bukannya', 'bul', 'bulan', 'bung', 'byk', 
                'cara', 'caranya', 'cer', 'cikgu', 'ckp', 'cuba', 'cukup', 'cukupkah', 'cukuplah', 'cuma', 
                'dah', 'dahulu', 'dalam', 'dalamnya', 'dan', 'dapat', 'dapati', 'dapatkah', 'dapatlah', 'dari', 'daripada', 'daripadaku', 'daripadamu', 'daripadanya', 'dato', 'datuk', 'dekat', 'demi', 'demikian', 'demikianlah', 'den', 'dengan', 'dengannya', 'depan', 'dew', 'dgn', 'di', 'dia', 'diakhiri', 'diakhirinya', 'dialah', 'diantara', 'diantaranya', 'diri', 'dirinya', 'disebabkan', 'dlm', 'dong', 'dont', 'dorang', 'dpt', 'dr', 'dsp', 'dua', 'dulu', 
                'ehh', 'empat', 'enam', 'eng', 'enggak', 'enggaknya', 'engkau', 'engkaukah', 'engkaulah', 'engkaupun', 'entah', 'entahlah', 'even', 'ever', 
                'got', 'guna', 'gunakan', 
                'hadapan', 'hai', 'haji', 'hal', 'hamba', 'hampir', 'hampir-hampir', 'hanya', 'hanyalah', 'harem', 'haremm', 'hari', 'harus', 'haruslah', 'harusnya', 'helai', 'hendak', 'hendaklah', 'hendaknya', 'hingga', 'hj', 'huih', 
                'ia', 'iaitu', 'ialah', 'ianya', 'ibarat', 'ibaratkan', 'ibaratnya', 'ibu', 'ingin', 'inginkah', 'inginkan', 'ini', 'inikah', 'inilah', 'int', 'ir', 'itu', 'itukah', 'itulah', 
                'jadi', 'jadilah', 'jadinya', 'jangan', 'jangankan', 'janganlah', 'jd', 'jgn', 'jika', 'jikalau', 'jua', 'juapun', 'juga', 'jumlah', 'jumlahnya', 'justeru', 'justru', 'juta', 
                'kadang', 'kak', 'kakak', 'kala', 'kalakian', 'kalau', 'kalaulah', 'kalaupun', 'kalian', 'kami', 'kamikah', 'kamilah', 'kamipun', 'kamu', 'kamukah', 'kamulah', 'kamupun', 'kan', 'kanan', 'kapan', 'kapankah', 'kapanpun', 'karena', 'karenanya', 'kat', 'kata', 'katakan', 'katakanlah', 'katanya', 'kau', 'ke', 'keb', 'kecuali', 'kedua', 'keduanya', 'keja', 'keje', 'kelima', 'kemudian', 'kenapa', 'kepada', 'kepadaku', 'kepadakulah', 'kepadamu', 'kepadanya', 'kepadanyalah', 'kerana', 'kerananya', 'ketika', 'khususnya', 'kini', 'kinilah', 'kira', 'kira-kira', 'kiranya', 'kiri', 'kita', 'kitalah', 'kok', 'kpd', 'ku', 'kurang', 
                'lagi', 'lagian', 'lah', 'lain', 'lainnya', 'laksanabagai', 'lalu', 'langsung', 'lapan', 'lebih', 'leh', 'lena', 'lepas', 'let', 'lima', 'luar', 
                'macam', 'maha', 'mahu', 'mahukah', 'mahupun', 'mak', 'maka', 'makanya', 'makin', 'malah', 'malahan', 'mama', 'mampu', 'mampukah', 'mana', 'manakah', 'manakala', 'manalagi', 'manapun', 'masa', 'masalah', 'masalahnya', 'masih', 'masihkah', 'masing', 'masing-masing', 'mau', 'maupun', 'mcm', 'md', 'meh', 'mejar', 'memang', 'mereka', 'merekalah', 'merekapun', 'merupakan', 'meski', 'meskipun', 'mesti', 'met', 'mmg', 'mu', 'mula', 'mulai', 'mulailah', 'mulanya', 'mungkin', 'mungkinkah', 
                'nah', 'nak', 'namun', 'nanti', 'nantinya', 'nenek', 'nescaya', 'nian', 'niscaya', 'nk', 'nya', 'nyaris', 'nyatanya', 
                'olah', 'oleh', 'olehnya', 'orang', 'org', 
                'pada', 'padahal', 'padamu', 'padanya', 'pak', 'paling', 'para', 'pasti', 'pastilah', 'pastu', 'patik', 'patut', 'patutkah', 'per', 'pergh', 'perghh', 'pergilah', 'perkara', 'perkaranya', 'perlu', 'perlukah', 'perlunya', 'pernah', 'petang', 'pon', 'prof', 'puan', 'pukul', 'pula', 'puluh', 'pun', 'punya', 
                'rata', 'ratus', 'rupanya', 
                'saat', 'saatnya', 'sahaja', 'sajalah', 'saje', 'salam', 'saling', 'sama', 'sama-sama', 'samakah', 'sambil', 'sampai', 'sampai-sampai', 'sampaikan', 'sana', 'sane', 'sangat', 'sangatlah', 'satu', 'saya', 'sayalah', 'se', 'seandainya', 'sebab', 'sebabnya', 'sebagai', 'sebagaimana', 'sebagainya', 'sebagian', 'sebaik', 'sebaik-baiknya', 'sebaiknya', 'sebaliknya', 'sebanyak', 'sebegini', 'sebegitu', 'sebelas', 'sebelum', 'sebelummu', 'sebelumnya', 'sebenarnya', 'sebentar', 'seberapa', 'sebesar', 'sebetulnya', 'sebilan', 'sebisanya', 'sebuah', 'sebut', 'sebutlah', 'sebutnya', 'secara', 'secukupnya', 'sedang', 'sedangkan', 'sedemikian', 'sedikit', 'sedikitnya', 'sedikitpun', 'seenaknya', 'segala', 'segalanya', 'segera', 'seharusnya', 'sehingga', 'seingat', 'sejak', 'sejauh', 'sejenak', 'sejumlah', 'sejuta', 'sekadar', 'sekadarnya', 'sekali', 'sekali-kali', 'sekalian', 'sekaligus', 'sekalipun', 'sekarang', 'sekecil', 'seketika', 'sekiranya', 'sekitar', 'sekitarnya', 'sekurang-kurangnya', 'sekurangnya', 'sela', 'selain', 'selaku', 'selalu', 'selama', 'selama-lamanya', 'selamanya', 'selanjutnya', 'selepas', 'seluruh', 'seluruhnya', 'semacam', 'semakin', 'semalam', 'semampu', 'semampunya', 'semasa', 'semasih', 'semata', 'semata-mata', 'semaunya', 'sembilan', 'semenjak', 'sementara', 'semisal', 'semisalnya', 'sempat', 'semua', 'semuanya', 'semula', 'senantiasa', 'sendiri', 'sendirian', 'sendirinya', 'sentiasa', 'seolah', 'seolah-olah', 'seorang', 'seorangpun', 'sepanjang', 'sepantasnya', 'sepantasnyalah', 'separuh', 'sepatutnya', 'seperlunya', 'seperti', 'sepertinya', 'sepihak', 'sepuluh', 'seratus', 'seraya', 'seribu', 'sering', 'seringnya', 'serta', 'serupa', 'sesaat', 'sesama', 'sesampai', 'sesegera', 'sesekali', 'seseorang', 'sesiapa', 'sesuatu', 'sesuatunya', 'sesudah', 'sesudahnya', 'sesungguhnya', 'sesungguhnyakah', 'setelah', 'setempat', 'setengah', 'seterusnya', 'setiap', 'setiba', 'setibanya', 'setidak-tidaknya', 'setidaknya', 'seusai', 'sewaktu', 'siang', 'siapa', 'siapakah', 'siapapun', 'sila', 'sini', 'sinilah', 'sisi', 'situ', 'situlah', 'sri', 'suatu', 'sudah', 'sudahkah', 'sudahlah', 'suku', 'sungguh', 'sungguhpun', 'supaya', 'syahdah', 
                'tadi', 'tadinya', 'tahu', 'tahukah', 'tahun', 'tak', 'takda', 'takde', 'tan', 'tandas', 'tandasnya', 'tanpa', 'tanya', 'tanyakan', 'tanyakanlah', 'tanyanya', 'tapi', 'telah', 'tempat', 'tengah', 'tengku', 'tentang', 'tentu', 'tentulah', 'tentunya', 'tepi', 'terakhir', 'terasa', 'terbanyak', 'terdahulu', 'terdapat', 'terdiri', 'terhadap', 'terhadapmu', 'terhadapnya', 'teringat', 'teringat-ingat', 'terjadi', 'terjadilah', 'terjadinya', 'terlalu', 'terlebih', 'tersebut', 'tersebutlah', 'tertentu', 'terus', 'terutama', 'tetapi', 'tgh', 'tiada', 'tiadakah', 'tiadalah', 'tiap', 'tiap-tiap', 'tiba', 'tiba-tiba', 'tidak', 'tidakkah', 'tidaklah', 'tiga', 'tiga', 'suku', 'toh', 'tok', 'tryna', 'tuan', 'tuanku', 'tujuh', 'tun', 
                'umpama', 'umum', 'umumnya', 'untuk', 'untukmu', 'usai', 'ust', 'ustaz', 'ustazah', 'utara', 'utk', 
                'waalaikumussalam', 'waduh', 'wah', 'wahai', 'waktu', 'waktunya', 'walau', 'walaupun', 'wan', 'wasalam', 'wdir', 'woi', 'wong', 'wsalam', 'wui', 
                'xda', 'xde', 'xkan', 'xkira', 'xleh', 'xtahu', 
                'ya', 'ya', 'yaini', 'yaitu', 'yang', 'yb', 'yg']
    elif(lang == 'zh'):
        return ['零', '一', '二', '三', '四', '五', '六', '七', '八', '九', '二来', '两者',
                '一个', '一些', '一何', '一切', '一则', '一方面', '一旦', '一来', '一样', '一种', '一般', '一转眼', '万一', '一起', '一定',
                '上', '上下', '下', '下次', '后', '后者', '后天', '中', '前后', '前此', '前者', '前天', 
                '不', '不仅', '不但', '不光', '不单', '不只', '不外乎', '不如', '不妨', '不尽', '不尽然', '不得', '不怕', '不惟', '不成', '不拘', '不料', '不是', '不比', '不然', '不特', '不独', '不管', '不至于', '不若', '不论', '不过', '不问', '不能', '不会', 
                '与', '与其', '与其说', '与否', '与此同时', 
                '且', '且不说', '且说', 
                '个', '个别',
                '为', '为了', '为什么', '为何', '为止', '为此', '为着', 
                '乃', '乃至', '乃至于', 
                '么', '吗', '阿', 
                '之', '之一', '之所以', '之类', '之前', '之后',
                '乌乎', '乎', '乘', 
                '也', '也有', '也是', '也罢', '了',
                '于', '于是', '于是乎', '云云', '云尔',  '些', '亦', 
                '人', '人们', '人家', 
                '什', '什么', '什么样', 
                '今', '今天', '介于', 
                '仍', '仍旧', 
                '从', '从此', '从而', 
                '您', '你', '你们', '我', '我们', '他', '他人', '他们', '他们们', '们', '她', '她们', '它', '它们', '咱', '咱们', 
                '以', '以上', '以为', '以便', '以免', '以及', '以故', '以期', '以来', '以至', '以至于', '以致', '以后', '以前',
                '任', '任何', '任凭', 
                '会', '似的', 
                '但', '但凡', '但是', 
                '何', '何以', '何况', '何处', '何时', 
                '余外', '作为', '例如', 
                '使', '使得',  
                '依', '依据', '依照', 
                '便于', 
                '俺', '俺们', 
                '倘', '倘使', '倘或', '倘然', '倘若', 
                '借傥然', 
                '假使', '假如', '假若', 
                '做', '像', '儿', '先不先', 
                '光', '光是', 
                '全体', '全部', 
                '兮', '共', 
                '关于', '关于具体地说', '冒', '冲', '况且',
                '其', '其一', '其中', '其二', '其他', '其余', '其它', '其次', '其实',
                '具体地说', '具体说来', 
                '兼之', '内', 
                '再', '再其次', '再则', '再有', '再者', '再者说', '再说', '再次',
                '几', '几时', '几天', '几次',
                '凡', '凡是', 
                '凭', '凭借', 
                '出于', '出来', 
                '分', '分别', 
                '则', '则甚', 
                '别', '别人', '别处', '别是', '别的', '别管', '别说', 
                '到', '加之', '加以', '区', 
                '即', '即令', '即使', '即便', '即如', '即或', '即若', 
                '却', '去', '又', '又及', '及', '及其', '及至', 
                '反之', '反而', '反过来', '反过来说', 
                '受到', 
                '另', '另一方面', '另外', '另悉', 
                '只', '只当', '只怕', '只是', '只有', '只消', '只要', '只限', 
                '叫', '叮咚', 
                '可', '可以', '可是', '可见', '可能',
                '各', '各个', '各位', '各种', '各自', 
                '同', '同时', 
                '向', '向使', '向着', 
                '吓', '否则', '吧', '吧哒', '含', 
                '吱', '呀', '呃', '呕', '呗', '呜', '呜呼', '呢', '呵', '呵呵', '呸', '呼哧', '咋', '和', '咚', '咦', '咧', '咳', '哉', '哎', '哎呀', '哎哟', '哗', '哟', '哦', '哩', 
                '哪', '哪个', '哪些', '哪儿', '哪天', '哪年', '哪怕', '哪样', '哪边', '哪里', 
                '哼', '哼唷', '唉', '啊', '啐', '啥', '啦', '啪达', '啷当', '喂', '喏', '喔唷', '喽', '嗡', '嗡嗡', '嗬', '嗯', '嗳', '嘎', '嘎登', '嘘', '嘛', '嘻', '嘿', '嘿嘿', 
                '因', '因为', '因了', '因此', '因着', '因而', 
                '固然', 
                '在', '在下', '在于', 
                '地', '基于', '处在', 
                '多', '多么', '多少', 
                '大', '大家', '好', '好像',
                '如', '如上', '如上所述', '如下', '如何', '如其', '如同', '如是', '如果', '如此', '如若', 
                '始而', 
                '孰料', '孰知', 
                '宁', '宁可', '宁愿', '宁肯',  
                '对', '对于', '对待', '对方', '对比', 
                '将', 
                '尔', '尔后', '尔尔', 
                '尚且', 
                '就', '就是', '就是了', '就是说', '就算', '就要', '就会',
                '尽', '尽管', '尽管如此', '岂但', 
                '己', '已', '已矣', '已经', '巴', '巴巴', '年', '并', '并且', '庶乎', '庶几', '开外', '开始', '归', '归齐',
                '当', '当地', '当然', '当着', 
                '彼', '彼时', '彼此', 
                '往', '待', 
                '得', '得了', 
                '怎', '怎么', '怎么办', '怎么样', '怎奈', '怎样', 
                '总之', '总的来看', '总的来说', '总的说来', '总而言之', '恰恰相反', '惟其', '慢说',  
                '或', '或则', '或是', '或曰', '或者', 
                '截至', 
                '所', '所以', '所在', '所幸', '所有', 
                '才', '才会',
                '打从', '把', 
                '抑或',  
                '按', '按照', 
                '换句话说', '换言之', 
                '据', '据此', 
                '接着', 
                '故', '故此', '故而', 
                '无', '无宁', '无论', 
                '既', '既往', '既是', '既然', 
                '日', '时', '时候', 
                '是', '是以', '是的', 
                '替', '替代',  
                '旁人', '旁边'
                '有', '有些', '有关', '有及', '有时', '有的', 
                '望', '月', '更', '曾', 
                '朝', '朝着', 
                '本', '本人', '本地', '本着', '本身', 
                '来', '来着', '来到', '来自', '来说', 
                '极了', 
                '果然', '果真', 
                '某', '某个', '某些', '某某', 
                '根据', '欤', 
                '正值', '正如', '正巧', '正是', 
                '此', '此地', '此处', '此外', '此时', '此次', '此间', 
                '毋宁', 
                '每', '每当', '每次',
                '比', '比及', '比如', '比方', '比较', 
                '没奈何', 
                '沿', '沿着', '漫说', '点', '焉', 
                '然则', '然后', '然而', 
                '照', '照着', 
                '犹且', '犹自', 
                '甚且', '甚么', '甚或', '甚而', '甚至', '甚至于', 
                '用', '用来', 
                '由', '由于', '由是', '由此', '由此可见', 
                '的', '的确', '的话', 
                '直到', '相对而言', '省得', '看', '眨眼', 
                '着', '着呢', 
                '矣', '矣乎', '矣哉', 
                '离', '秒', '称', '竟而', '第', 
                '等', '等到', '等等', 
                '简言之', '简言之', '管', '类如', '紧接着', 
                '纵', '纵令', '纵使', '纵然', 
                '经', '经过', 
                '结果', '给', 
                '继之', '继后', '继而', 
                '综上所述', '罢了', '者', 
                '而', '而且', '而况', '而后', '而外', '而已', '而是', '而言', 
                '能', '能否', 
                '腾', '边', '过', 
                '自', '自个儿', '自从', '自各儿', '自后', '自家', '自己', '自打', '自身', 
                '至', '至于', '至今', '至若', '致', 
                '般的', 
                '若', '若夫', '若是', '若果', '若非', 
                '莫不然', '莫如', '莫若', '虽', '虽则', '虽然', '虽说', '被', 
                '要', '要不', '要不是', '要不然', '要么', '要是', 
                '譬喻', '譬如', 
                '让', '许多', '论', 
                '设使', '设或', '设若', 
                '诚如', '诚然', 
                '该', '说', '说来', '请', 
                '诸', '诸位', '诸如', 
                '谁', '谁人', '谁料', '谁知', 
                '贼死', '赖以', '赶', 
                '起', '起来', '起见', 
                '趁', '趁着', 
                '越是', '距', '跟', 
                '较', '较之', 
                '还', '还是', '还有', '还要', '还会', '还没',
                '这', '这一来', '这个', '这是', '这种', '这款', '这家', '这么', '这么些', '这么样', '这么点儿', '这些', '这会儿', '这儿', '这就是说', '这时', '这样', '这次', '这般', '这边', '这里', 
                '进而', '连', '连同', '逐步', 
                '那', '那个', '那么', '那么些', '那么样', '那些', '那会儿', '那儿', '那时', '那样', '那般', '那边', '那里', 
                '都', '都是', '都会', '都有', '鄙人', '鉴于', '针对', 
                '除', '除了', '除外', '除开', '除此之外', '除非', 
                '随', '随后', '随时', '随着', '难道说', 
                '非', '非但', '非徒', '非特', '非独', 
                '必然', '必须',
                '目前', '目前为止',
                '原来', '原本',
                '靠', '顺', '顺着', '首先', '唯有', '现在', '里面', '应该', '外面', '昨天', '明天', '导致', '最后', '毕竟', '想要']

def all(modifier='', zh=True):
    if(modifier == 'neg'):
        result = negation('en') + negation('zsm')
        if(zh):
            result += list(negation('zh').keys())
    elif(modifier == 'intsf'):
        result = intensifier('en')['high'] + intensifier('en')['low'] + intensifier('zsm')['high'] + intensifier('zsm')['low']
        if(zh):
            result += list(intensifier('zh').keys())
    elif(modifier == 'conj'):
        result = conjunction('en')['contrasting'] + conjunction('zsm')['contrasting']
        if(zh):
            result += list(conjunction('zh')['contrasting'].keys())
    elif(modifier == 'sw'):
        result = stopword('en') + stopword('zsm')
        if(zh):
            result += stopword('zh')
    else:
        result = negation('en') + negation('zsm') + \
            intensifier('en')['high'] + intensifier('en')['low'] + intensifier('zsm')['high'] + intensifier('zsm')['low'] + \
            conjunction('en')['contrasting'] + conjunction('zsm')['contrasting'] + \
            stopword('en') + stopword('zsm')
        if(zh):
            result += list(negation('zh').keys()) + list(intensifier('zh').keys()) + list(conjunction('zh')['contrasting'].keys()) + stopword('zh')
    return result
        
    
        


from setuptools import find_packages, setup
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='msiaLex',
    packages=find_packages(include=['msiaLex', 'msiaLex.data']),
    version='0.3.9.20',
    description='Malaysia Lexicon',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Khor Yuen Kei',
    author_email='khoryk1104@gmail.com',
    url='https://github.com/yuenkeiwac/msialex',
    license='MIT',
    install_requires=[], 
    setup_requires=['pytest-runner'], 
    tests_require=['pytest==6.2.5'],
    test_suite='tests'
)


import csv
import logging
from os import path

logging.basicConfig(
    level=logging.INFO,
    format='%(process)d | %(levelname)s | %(message)s'
)


# pylint: disable=too-many-locals
def _build_dict_from_csv(csv_path):
    """ Builds the Emoji to Sentiment dictionary from the CSV file. """

    emoji_sentiment_rankings = {}

    with open(csv_path, newline='') as csv_file:
        csv_reader = csv.reader(csv_file)
        _header_row = next(csv_reader)
        for row in csv_reader:
            emoji = row[0]
            unicode_codepoint = row[1]
            occurrences = int(row[2])
            position = float(row[3])
            negative = float(row[4])
            neutral = float(row[5])
            positive = float(row[6])
            unicode_name = row[7]
            unicode_block = row[8]
            sentiment_score = float(
                '{:.3f}'.format((positive - negative) / occurrences)
            )

            emoji_sentiment_rankings[emoji] = {
                'unicode_codepoint': unicode_codepoint,
                'occurrences': occurrences,
                'position': position,
                'negative': negative,
                'neutral': neutral,
                'positive': positive,
                'unicode_name': unicode_name,
                'unicode_block': unicode_block,
                'sentiment_score': sentiment_score
            }

    return emoji_sentiment_rankings


def get_emoji_sentiment_rank(emoji):
    """ Returns the Sentiment Data mapped to the specified Emoji. """

    return EMOJI_SENTIMENT_DICT[emoji]


EMOJI_SENTIMENT_DICT = _build_dict_from_csv(
    path.join(
        path.abspath(path.dirname(__file__)),
        'data/Emoji_Sentiment_Data_v2.0.csv'
    )
)
